==> haskell-hakyll-4.9.7.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hakyll
version: 4.9.7.0
id: hakyll-4.9.7.0-AJ2hzvxGzXIKwWSFzWZTYY
key: hakyll-4.9.7.0-AJ2hzvxGzXIKwWSFzWZTYY
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: http://jaspervdj.be/hakyll
synopsis: A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:
    .
    * <http://jaspervdj.be/hakyll>
    .
    If you seek assistance, there'\''s:
    .
    * A google group: <http://groups.google.com/group/hakyll>
    .
    * An IRC channel, @#hakyll@ on freenode
    .
    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.
category: Web
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Configuration Hakyll.Core.Dependencies Hakyll.Core.File
    Hakyll.Core.Identifier Hakyll.Core.Identifier.Pattern
    Hakyll.Core.Item Hakyll.Core.Metadata Hakyll.Core.Routes
    Hakyll.Core.Rules Hakyll.Core.UnixFilter Hakyll.Core.Util.String
    Hakyll.Core.Writable Hakyll.Main Hakyll.Web.CompressCss
    Hakyll.Web.Feed Hakyll.Web.Html Hakyll.Web.Html.RelativizeUrls
    Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Paginate Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List
hidden-modules: Data.List.Extended Data.Yaml.Extended Hakyll.Check
                Hakyll.Core.Compiler.Internal Hakyll.Core.Compiler.Require
                Hakyll.Core.Item.SomeItem Hakyll.Core.Logger Hakyll.Core.Provider
                Hakyll.Core.Provider.Internal Hakyll.Core.Provider.Metadata
                Hakyll.Core.Provider.MetadataCache Hakyll.Core.Rules.Internal
                Hakyll.Core.Runtime Hakyll.Core.Store Hakyll.Core.Util.File
                Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
                Hakyll.Preview.Poll Hakyll.Preview.Server
abi: c050f45303b3e0ad19560ba2b184477a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hakyll-4.9.7.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/hakyll-4.9.7.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/hakyll-4.9.7.0
hs-libraries: HShakyll-4.9.7.0-AJ2hzvxGzXIKwWSFzWZTYY
depends:
    base-4.9.0.0 binary-0.8.3.0
    blaze-html-0.8.1.3-5umpHbJSFbGGX5TQ5mnIPt
    blaze-markup-0.7.1.1-VJaDzmYXPW8F1IHSBweDX bytestring-0.10.8.1
    containers-0.5.7.1 cryptohash-0.11.9-Euve7brGLaM2bzKmxTqm1a
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr deepseq-1.4.2.0
    directory-1.2.6.2 filepath-1.4.1.0
    fsnotify-0.2.1-BqlufDCrIeNAMMQtJtCOHF
    http-conduit-2.2.3.1-FQ9V4eRkY0JFugCQX4MJCH
    http-types-0.9.1-3nvMCSru4dgGbycKqlKoUe
    lrucache-1.2.0.0-8hasrZyscuy5TbcNiCkcKY
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.3.2-GMjPV5zpIjuBSljTanWiH
    network-uri-2.6.1.0-FJ8JXDcVJz8KYX76kkCObd
    optparse-applicative-0.13.2.0-7Y0agREbHDlBXdHE81XeQP
    pandoc-1.19.2.1-FWbmxybQBBBH0cyXo1AoJE
    pandoc-citeproc-0.10.4.1-F061zm52Ldr132qbZ20QV5
    parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr process-1.4.2.0
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
    regex-tdfa-1.2.2-ITZHc3hWBSU2Doba6qXtEU
    resourcet-1.1.9-4wjmwiYhI4Y4ny0clYPjM8
    scientific-0.3.4.15-GEIRVwGBHHyElVCNt38fm3
    system-filepath-0.4.13.4-Hs7XtMIHiuY7X1m0lKul82
    tagsoup-0.14.1-5UpYkVoOhOt4iyOyy0sWwj
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    wai-3.2.1.1-OfWV8JQuvWB8nxi8pXkD1
    wai-app-static-3.1.6.1-98JSOZ7O0KJ4xK1AR0WjQo
    warp-3.2.12-6Y4kitQMsI8Cw3Gag1W6lt
    yaml-0.8.23-7FKDxIZKIEy2mzkOBF5oCs
haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html: /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hakyll-4.9.7.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hakyll
version: 4.9.7.0
id: hakyll-4.9.7.0-94evapU2NViJZ6t64aX7VF
key: hakyll-4.9.7.0-94evapU2NViJZ6t64aX7VF
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: http://jaspervdj.be/hakyll
synopsis: A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:
    .
    * <http://jaspervdj.be/hakyll>
    .
    If you seek assistance, there'\''s:
    .
    * A google group: <http://groups.google.com/group/hakyll>
    .
    * An IRC channel, @#hakyll@ on freenode
    .
    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.
category: Web
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Configuration Hakyll.Core.Dependencies Hakyll.Core.File
    Hakyll.Core.Identifier Hakyll.Core.Identifier.Pattern
    Hakyll.Core.Item Hakyll.Core.Metadata Hakyll.Core.Routes
    Hakyll.Core.Rules Hakyll.Core.UnixFilter Hakyll.Core.Util.String
    Hakyll.Core.Writable Hakyll.Main Hakyll.Web.CompressCss
    Hakyll.Web.Feed Hakyll.Web.Html Hakyll.Web.Html.RelativizeUrls
    Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Paginate Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List
hidden-modules: Data.List.Extended Data.Yaml.Extended Hakyll.Check
                Hakyll.Core.Compiler.Internal Hakyll.Core.Compiler.Require
                Hakyll.Core.Item.SomeItem Hakyll.Core.Logger Hakyll.Core.Provider
                Hakyll.Core.Provider.Internal Hakyll.Core.Provider.Metadata
                Hakyll.Core.Provider.MetadataCache Hakyll.Core.Rules.Internal
                Hakyll.Core.Runtime Hakyll.Core.Store Hakyll.Core.Util.File
                Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
                Hakyll.Preview.Poll Hakyll.Preview.Server
abi: f2657907a3ea3ade3ae64b506a659075
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hakyll-4.9.7.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/hakyll-4.9.7.0
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/hakyll-4.9.7.0
hs-libraries: HShakyll-4.9.7.0-94evapU2NViJZ6t64aX7VF
depends:
    base-4.9.0.0 binary-0.8.3.0
    blaze-html-0.8.1.3-5umpHbJSFbGGX5TQ5mnIPt
    blaze-markup-0.7.1.1-VJaDzmYXPW8F1IHSBweDX bytestring-0.10.8.1
    containers-0.5.7.1 cryptohash-0.11.9-Euve7brGLaM2bzKmxTqm1a
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr deepseq-1.4.2.0
    directory-1.2.6.2 filepath-1.4.1.0
    fsnotify-0.2.1-BqlufDCrIeNAMMQtJtCOHF
    http-conduit-2.2.3.1-7sLRAIMiU4AA4g0OVoEjGY
    http-types-0.9.1-3nvMCSru4dgGbycKqlKoUe
    lrucache-1.2.0.0-8hasrZyscuy5TbcNiCkcKY
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.3.2-GMjPV5zpIjuBSljTanWiH
    network-uri-2.6.1.0-FJ8JXDcVJz8KYX76kkCObd
    optparse-applicative-0.13.2.0-7Y0agREbHDlBXdHE81XeQP
    pandoc-1.19.2.1-4ljxLNqYIwAJLAlOga0lhn
    pandoc-citeproc-0.10.4.1-3xVOOy7d2L5CHH51qFKFHm
    parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr process-1.4.2.0
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
    regex-tdfa-1.2.2-ITZHc3hWBSU2Doba6qXtEU
    resourcet-1.1.9-5Fmv0DqXfJBCCiUazI0vW3
    scientific-0.3.4.15-GEIRVwGBHHyElVCNt38fm3
    system-filepath-0.4.13.4-Hs7XtMIHiuY7X1m0lKul82
    tagsoup-0.14.1-5UpYkVoOhOt4iyOyy0sWwj
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    wai-3.2.1.1-OfWV8JQuvWB8nxi8pXkD1
    wai-app-static-3.1.6.1-3EHEtcerNrM3XchOu1nnT7
    warp-3.2.12-6Y4kitQMsI8Cw3Gag1W6lt
    yaml-0.8.23-IlqoFsrNCUI6UYXTLgsyQ1
haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html: /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
